@@ -18,13 +18,16 @@ size_t ADM_fread (void *ptr, size_t size, size_t n, FILE *sstream);
 size_t ADM_fwrite (void *ptr, size_t size, size_t n, FILE *sstream);
 FILE  *ADM_fopen (const char *file, const char *mode);
 int    ADM_fclose (FILE *file);
+int    ADM_unlink(const char *filename);
+int ADM_access(const char *path, int mode);
 
 extern void *ADM_alloc(size_t size);
 extern void *ADM_calloc(size_t nbElm,size_t elSize);
 extern void *ADM_realloc(void *in,size_t size);
 extern void ADM_dezalloc(void *ptr);
 extern char *ADM_strdup( const char *in);
-extern char *slashToBackSlash(const char *in);
+extern char *backSlashToForward(const char *in);
+extern char *forwardSlashToBack(const char *in);
 typedef void *(* adm_fast_memcpy)(void *to, const void *from, size_t len);
 extern adm_fast_memcpy myAdmMemcpy;
 
@@ -38,6 +41,10 @@ extern adm_fast_memcpy myAdmMemcpy;
 #define fwrite  ADM_fwrite
 #define fopen   ADM_fopen
 #define fclose  ADM_fclose
+#ifdef __WIN32
+#define unlink  ADM_unlink
+#define access  ADM_access
+#endif
 
 #ifndef __APPLE__
 #ifndef ADM_LEGACY_PROGGY
@@ -66,11 +73,13 @@ extern adm_fast_memcpy myAdmMemcpy;
         #define LLX "I64x"
         #define LLU "I64u"
         
-        #define cleanupPath(x) slashToBackSlash(x)
+        #define cleanupPath(x) backSlashToForward(x)
+		#define fixupPath(x) forwardSlashToBack(x)
 #else
         #define LLX "llx"
         #define LLU "llu"
         #define cleanupPath(x) ADM_strdup(x)
+		#define fixupPath(x) ADM_strdup(x)
 #endif
 
 
