@@ -16,7 +16,7 @@
  ***************************************************************************/
 #include "config.h"
 
-#if defined( OSS_SUPPORT ) && !defined(CYG_MANGLING)
+#if defined( OSS_SUPPORT ) && !defined(ADM_WIN32)
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -26,10 +26,15 @@
 #include <fcntl.h>
 #include <sys/ioctl.h>
 
-#if defined(ADM_BSD_FAMILY) && !defined(__FreeBSD__)
+#if defined(ADM_BSD_FAMILY) && !defined(__FreeBSD__) && !defined(__OpenBSD__)
 	#include <soundcard.h>
 	const char *dsp = DEVOSSAUDIO;;
 
+#elif defined(__OpenBSD__)
+	#include <soundcard.h>
+	const char *dsp = "/dev/audio";
+	const char *device_mixer = "/dev/mixer";
+
 #else
 	#include <sys/soundcard.h>
 	const char *dsp = "/dev/dsp";
@@ -39,7 +44,7 @@
  
  
 
-#include "ADM_library/default.h"
+#include "default.h"
 #include "ADM_audiodevice.h"
 #include <ADM_assert.h>
 #include  "ADM_audiodevice/ADM_deviceoss.h"
@@ -110,7 +115,7 @@ uint8_t ossAudioDevice::init(uint8_t channels, uint32_t fq)
     if (oss_fd == -1) {
 	if( errno == EACCES )
 	{
-          GUI_Error_HIG(_("Could not open OSS audio device"), _("Check the permissions for /dev/dsp."));
+          GUI_Error_HIG(QT_TR_NOOP("Could not open OSS audio device"), QT_TR_NOOP("Check the permissions for /dev/dsp."));
 	  }
 	else
            printf("\n Error initializing OSS: Error : %d", errno);
