@@ -47,7 +47,6 @@ extern "C"
 #include "ADM_codecs/ADM_codec.h"
 #include "ADM_codecs/ADM_mjpeg.h"
 #include "ADM_codecs/ADM_codecNull.h"
-#include "ADM_codecs/ADM_rgb16.h"
 #include "ADM_codecs/ADM_uyvy.h"
 #include "ADM_codecs/ADM_xvideco.h"
 
@@ -65,7 +64,6 @@ extern "C"
 #include "ADM_codecs/ADM_theora_dec.h"
 #endif
 #include "ADM_codecs/ADM_mpeg.h"
-#include "ADM_codecs/ADM_png.h"
 #include "ADM_toolkit/toolkit.hxx"
 #include <ADM_assert.h>
 #include "prefs.h"
@@ -266,13 +264,11 @@ getDecoder (uint32_t fcc, uint32_t w, uint32_t h, uint32_t extraLen,
 
       return (decoders *) (new decoderFFhuff (w, h, extraLen, extraData,bpp));
     }
-#ifdef USE_PNG
   if (fourCC::check (fcc, (uint8_t *) "PNG "))
     {
 
-      return (decoders *) (new decoderPng (w, h));
+      return (decoders *) (new decoderFFPng (w, h));
     }
-#endif
  if (fourCC::check (fcc, (uint8_t *) "cvid"))
     {
 
@@ -399,21 +395,18 @@ if (fourCC::check (fcc, (uint8_t *) "MJPG")
       return (decoders *) (new decoderFFVP6F (w, h,extraLen,extraData));
     }
 
+  if (fourCC::check (fcc, (uint8_t *) "BMP "))
+  {
+	  printf ("\n using BMP codec\n");
+	  return (decoders *) (new decoderFFBmp(w, h, extraLen, extraData));
+  }
 
-  if ((fcc == 0) || fourCC::check (fcc, (uint8_t *) "RGB "))
-    {
-      // RGB 16 Codecs
-      printf ("\n using RGB codec\n");
-      return (decoders *) (new decoderRGB16 (w, h, 1, bpp));
+  if (fcc == 0 || fourCC::check(fcc, (uint8_t *) "RGB ") || fourCC::check(fcc, (uint8_t *) "DIB "))
+  {
+	  printf ("\n using Rawvideo codec, BPP: %d\n", bpp);
+	  return (decoders *) (new decoderFFRaw(w, h, bpp));
+  }
 
-    }
- if ((fcc == 0) || fourCC::check (fcc, (uint8_t *) "DIB "))
-    {
-      // RGB 16 Codecs
-      printf ("\n using DIB codec\n");
-      return (decoders *) (new decoderRGB16 (w, h, 0, bpp));
-
-    }
   if (isMpeg12Compatible (fcc))
     {
       uint32_t lavcodec_mpeg = 0;
