@@ -36,6 +36,9 @@ extern "C"
 #define HANDLE ((x264_t *)_handle)
 #define PICS ((x264_picture_t *)_pic)
 
+#ifdef __WIN32
+extern void convertPathToAnsi(const char *path, char **ansiPath);
+#endif
 
 typedef struct avcc		// for avcc atom
 {
@@ -109,8 +112,16 @@ uint8_t X264Encoder::preamble (uint32_t fps1000, ADM_x264Param * zparam)
   MKPARAM(i_bframe,MaxBFrame);
   MKPARAM(i_bframe_bias,Bias);
   MKPARAM( b_bframe_pyramid,BasReference );
+
+#if X264_BUILD < 65
   MKPARAM(analyse. b_bidir_me,BidirME );
+#endif
+
+#if X264_BUILD >= 63
+  MKPARAM( i_bframe_adaptive, Adaptative);
+#else
   MKPARAM( b_bframe_adaptive, Adaptative);
+#endif
   MKPARAM( analyse.b_weighted_bipred, Weighted);
   MKPARAM( b_cabac , CABAC);
   MKPARAM( analyse.i_trellis, Trellis);
@@ -118,12 +129,16 @@ uint8_t X264Encoder::preamble (uint32_t fps1000, ADM_x264Param * zparam)
 #define MIN_RDO 6
   if(zparam->PartitionDecision+1>=MIN_RDO)
   {
+#if X264_BUILD >= 65
+	  param.analyse.i_subpel_refine = zparam->PartitionDecision + 1;
+#else
       int rank,parity;
       rank=((zparam->PartitionDecision+1-MIN_RDO)>>1)+MIN_RDO;
       parity=(zparam->PartitionDecision+1-MIN_RDO)&1;
       
       param.analyse.i_subpel_refine=rank;
       param.analyse.b_bframe_rdo=parity;
+#endif
   }
   MKPARAM(analyse.b_chroma_me,ChromaME);
   MKPARAM(b_deblocking_filter,DeblockingFilter);
@@ -136,6 +151,11 @@ uint8_t X264Encoder::preamble (uint32_t fps1000, ADM_x264Param * zparam)
   MKPARAM(analyse.b_transform_8x8,_8x8);
   MKPARAM(analyse.b_mixed_references,MixedRefs);
   MKPARAM(analyse.i_noise_reduction,NoiseReduction);
+
+#if X264_BUILD >= 62
+  MKPARAM(rc.i_aq_mode, AqMode);
+  MKPARAMF(rc.f_aq_strength, AqStrength);
+#endif
   
 #define MES(x,y) if(zparam->x) {param.analyse.inter |=X264_ANALYSE_##y;printf("[x264] "#x" is on\n");}
   param.analyse.inter=0;
@@ -238,17 +258,20 @@ uint8_t X264Encoder::encode (ADMImage * in, ADMBitstream * out)
   PICS->img.i_csp = X264_CSP_I420;
   PICS->img.i_plane = 3;
 
-  PICS->img.plane[0] = in->data;	// Y
-  PICS->img.plane[2] = in->data + _w * _h;	// u
-  PICS->img.plane[1] = in->data + ((_w * _h * 5) >> 2);	// v
-  PICS->img.i_stride[0] = _w;
-  PICS->img.i_stride[1] = _w >> 1;
-  PICS->img.i_stride[2] = _w >> 1;
+  if (in)
+  {
+	  PICS->img.plane[0] = in->data;	// Y
+	  PICS->img.plane[2] = in->data + _w * _h;	// u
+	  PICS->img.plane[1] = in->data + ((_w * _h * 5) >> 2);	// v
+	  PICS->img.i_stride[0] = _w;
+	  PICS->img.i_stride[1] = _w >> 1;
+	  PICS->img.i_stride[2] = _w >> 1;
 
-  PICS->i_type = X264_TYPE_AUTO;
-  PICS->i_pts = curFrame;
+	  PICS->i_type = X264_TYPE_AUTO;
+	  PICS->i_pts = curFrame;
+  }
 
-  if (x264_encoder_encode (HANDLE, &nal, &nbNal, PICS, &pic_out) < 0)
+  if (x264_encoder_encode (HANDLE, &nal, &nbNal, in ? PICS : NULL, &pic_out) < 0)
   {
 	  printf ("[x264] Error encoding\n");
 	  return 0;
@@ -257,7 +280,6 @@ uint8_t X264Encoder::encode (ADMImage * in, ADMBitstream * out)
 
   if (nbNal == 0)
   {
-      printf("[X264] No Nal for frame %u (delay ?)\n",curFrame);
       out->len=0;
 	  return 1;
   }
@@ -414,36 +436,36 @@ uint8_t
   x264_param_default (&param);
   memcpy(&admParam,zparam,sizeof(admParam));
 
-  // in case of pass 1 we switch off some options
-  // As mplayer does it
-  admParam.PartitionDecision = 1;
-  admParam.Method = X264_ME_DIA;
-  
-  admParam._8x8 = 0;
-  admParam._8x8P = 0;
-  admParam._8x8B = 0;
-  admParam._8x8I = 0;
-  admParam._4x4I = 0;
-  admParam.Weighted = 0;
-  admParam.Trellis = 0;
-  
-//  param.rc.i_rc_buffer_size=-1;
 #if X264_BUILD >=48
-  param.rc.i_rc_method=X264_RC_CQP;
+  param.rc.i_rc_method=X264_RC_ABR;
+#else
+  param.rc.b_cbr = 1;
 #endif
-  param.rc.i_qp_constant = 2;
+  param.rc.i_bitrate = val;
 
   param.rc.b_stat_write = 1;
   param.rc.b_stat_read = 0;
   if (!zparam->logfile)
-    param.rc.psz_stat_out = "/tmp/x264_log.tmp";
+    param.rc.psz_stat_out = ADM_strdup("/tmp/x264_log.tmp");
   else
-    param.rc.psz_stat_out = zparam->logfile;
+  {
+#ifdef __WIN32
+	char *logFile;
+
+	convertPathToAnsi(zparam->logfile, &logFile);
+	param.rc.psz_stat_out = logFile;
+#else
+	param.rc.psz_stat_out = ADM_strdup(zparam->logfile);
+#endif
+  }
+
   printf ("[x264] codec using %s as statfile\n", param.rc.psz_stat_out);
   return preamble (fps1000, &admParam);
 }
 X264EncoderPass1::~X264EncoderPass1 ()
 {
+	delete param.rc.psz_stat_out;
+	param.rc.psz_stat_out = NULL;
   stopEncoder ();
 }
 //*********************Pass1***************
@@ -470,17 +492,28 @@ uint8_t
   param.rc.b_stat_write = 0;
   param.rc.b_stat_read = 1;
 
-
   if (!zparam->logfile)
-    param.rc.psz_stat_in = "/tmp/x264_log.tmp";
+    param.rc.psz_stat_in = ADM_strdup("/tmp/x264_log.tmp");
   else
-    param.rc.psz_stat_in = zparam->logfile;
+  {
+#ifdef __WIN32
+	char *logFile;
+
+	convertPathToAnsi(zparam->logfile, &logFile);
+	param.rc.psz_stat_in = logFile;
+#else
+	param.rc.psz_stat_in = ADM_strdup(zparam->logfile);
+#endif
+  }
+
   printf ("[x264] using %s as statfile\n", param.rc.psz_stat_in);
 
   return preamble (fps1000, &admParam);
 }
 X264EncoderPass2::~X264EncoderPass2 ()
 {
+	delete param.rc.psz_stat_in;
+	param.rc.psz_stat_in = NULL;
   stopEncoder ();
 }
   // Create avcc atom as extradata
