@@ -34,7 +34,8 @@
     ADM_COLOR_YUV422P,
 	ADM_COLOR_YUV411,
 	ADM_COLOR_YUV444,
-	ADM_COLOR_GRAY8
+	ADM_COLOR_GRAY8,
+	ADM_COLOR_PAL8
  } ADM_colorspace;
 #define ADM_COLOR_BACKWARD 0x8000
 #define ADM_COLOR_MASK     0x7FFF
