@@ -26,7 +26,7 @@ Not optimised for speed at all, should take the one from ffmpeg
 
 #include <string.h>
 
-#include "ADM_library/default.h"
+#include "ADM_utilities/default.h"
 
 #include <ADM_assert.h>
 #include "colorspace.h"
