@@ -21,8 +21,8 @@ typedef enum
 	ADM_TS,
 	ADM_ES,
 	ADM_MP4,
-	ADM_OGM,
 	ADM_PSP,
+	ADM_OGM,
 	ADM_FLV,
         ADM_MATROSKA,
 	ADM_DUMMY,
@@ -47,8 +47,8 @@ const ADM_FORMAT_DESC ADM_allOutputFormat[]=
   {ADM_TS,QT_TR_NOOP("MPEG-TS (A+V)")},
   {ADM_ES,QT_TR_NOOP("MPEG video")},
   {ADM_MP4,QT_TR_NOOP("MP4")},
+  {ADM_PSP,QT_TR_NOOP("MP4 (PSP)")},
   {ADM_OGM,QT_TR_NOOP("OGM")},
-  {ADM_PSP,QT_TR_NOOP("PSP")},
   {ADM_FLV,QT_TR_NOOP("FLV")},
   {ADM_MATROSKA,QT_TR_NOOP("MKV")},
   {ADM_DUMMY,QT_TR_NOOP("DUMMY")}
