@@ -36,7 +36,6 @@ protected:
 
   X264Encoder * _codec;
   char *_logfile;
-  uint32_t _delayed;
   uint32_t _availableFrames;
   uint32_t _q;
   uint32_t _pass1Done;
@@ -47,6 +46,7 @@ protected:
 public:
     EncoderX264 (COMPRES_PARAMS * conf);
    ~EncoderX264 ();
+  virtual int getRequirements (void);
   virtual uint8_t isDualPass (void);	// mjpeg is always monopass
   virtual uint8_t configure (AVDMGenericVideoStream * instream);
   virtual uint8_t encode (uint32_t frame, ADMBitstream *out);
