@@ -266,7 +266,7 @@ char realstring[250];
 		fclose(fd);
 		return 0;
 	    }
-	    _offset = bmph.size + 14;
+	    //_offset = bmph.size + 14;
 	    w = bmph.width;
 	    h = bmph.height;
 		bpp = bmph.numBitsPerPlane;
@@ -278,16 +278,17 @@ char realstring[250];
 	//_______________________
     case PIC_JPEG:
 	{
-	    uint16_t tag = 0, count = 0, off;
+	    uint16_t tag = 0, off;
 
 	    _offset = 0;
 	    fseek(fd, 0, SEEK_SET);
 	    read16(fd);	// skip jpeg ffd8
-	    while (count < 10 && tag != 0xFFC0) {
+	    while (!feof(fd) && tag != 0xFFC0) {
 
 		tag = read16(fd);
 		if ((tag >> 8) != 0xff) {
 		    printf("invalid jpeg tag found (%x)\n", tag);
+			continue;
 		}
 		if (tag == 0xFFC0) {
 		    read16(fd);	// size
@@ -296,6 +297,7 @@ char realstring[250];
 		    w = read16(fd);
                     if(w&1) w++;
                     if(h&1) h++;
+					break;
 		} else {
 
 		    off = read16(fd);
@@ -308,10 +310,9 @@ char realstring[250];
 			    off);
 		    fseek(fd, off - 2, SEEK_CUR);
 		}
-		count++;
 	    }
 	    if (tag != 0xffc0) {
-		printf("Cannot fint start of frame\n");
+		printf("Cannot find start of frame\n");
 		fclose(fd);
 		return 0;
 	    }
@@ -325,11 +326,11 @@ char realstring[250];
 
 	    fseek(fd, 10, SEEK_SET);
 
-#define MK32() (fcc_tab[0]+(fcc_tab[1]<<8)+(fcc_tab[2]<<16)+ \
-						(fcc_tab[3]<<24))
+//#define MK32() (fcc_tab[0]+(fcc_tab[1]<<8)+(fcc_tab[2]<<16)+ \
+						//(fcc_tab[3]<<24))
 
 	    fread(fcc_tab, 4, 1, fd);
-	    _offset = MK32();
+	    //_offset = MK32();
 	    // size, width height follow as int32 
 	    fread(&bmph, sizeof(bmph), 1, fd);
 #ifdef ADM_BIG_ENDIAN
@@ -406,7 +407,7 @@ char realstring[250];
 	        break;
 	    case PIC_BMP:
 	    case PIC_BMP2:
-	        _video_bih.biCompression = _videostream.fccHandler = fourCC::get((uint8_t *) "DIB ");
+	        _video_bih.biCompression = _videostream.fccHandler = fourCC::get((uint8_t *) "BMP ");
 	        break;
 	    case PIC_PNG:
 	        _video_bih.biCompression = _videostream.fccHandler =
@@ -440,4 +441,4 @@ FILE* picHeader::openFrameFile(uint32_t frameNum)
 	sprintf(filename, _fileMask, frameNum + _first);
 
 	return fopen(filename, "rb");
-}
+}
\ No newline at end of file
