@@ -35,7 +35,7 @@
 #include <math.h>
 
 #include "default.h"
-#include <ADM_assert.h>
+#include "ADM_assert.h"
 
 //#define TS_VERBOSE 1
 
@@ -406,9 +406,15 @@ _againBranch:
                         }
                         return 1;
                 }
-                // Udate info on that track
-                updateTracker(pid,left);
-                parser->forward(left);
+
+				parser->forward(left);
+
+                // Update info on that track
+				if (TS_PacketSize == 192 && left > 4)
+					left -= 4; // Remove timestamp of m2ts packet
+
+				updateTracker(pid,left);
+                
                 goto _againBranch;
         }
         // Payload present, read header
@@ -496,9 +502,15 @@ _againBranch:
                 }
                 return 1;
         }
+
+		parser->forward(left);
+
         // update info
+		if (TS_PacketSize == 192 && left > 4)
+			left -= 4; // Remove timestamp of m2ts packet
+
         updateTracker(pid,left);
-        parser->forward(left);
+
         goto _againBranch;
 }
 //***********************************
@@ -552,8 +564,12 @@ _again:
         pid=parser->read16i();
         if((pid>>8) & TS_UNIT_START) payloadunit=1;
         pid&=0x1fff; // remove flags
+
+#ifdef TS_VERBOSE
         if(discarded)
                 printf("Ts: Discontinuity of %lu at %"LLX" pid:%lx\n",discarded,abs,pid);
+#endif
+
         // Start of packet..
         left=TS_PacketSize-3;
         if(_probeSize)
@@ -778,28 +794,15 @@ uint8_t dmx_demuxerTS::getInfoPSI(uint32_t *oconsumed,uint32_t *olen)
 */
 uint8_t         dmx_demuxerTS::syncH264( uint8_t *stream,uint64_t *abs,uint64_t *r,uint64_t *pts,uint64_t *dts)
 {
-uint32_t val,hnt;
+uint32_t hnt;
 retry:
          *r=0;
 
-                val=0;
-                hnt=0;
+		 hnt = (read8i() << 16) | (read8i() << 8) | read8i();
 
-                // preload
-                hnt=(read8i()<<24) + (read8i()<<16) +(read8i()<<8)+(read8i());
-                if(_lastErr)
+                while (hnt >> 8 != 1)
                 {
-                        _lastErr=0;
-                        printf("\n io error , aborting sync\n");
-                        return 0;       
-                }
-
-                while((hnt!=1))
-                {
-
-                        hnt<<=8;
-                        val=read8i();
-                        hnt+=val;
+					hnt = (hnt << 8) | read8i();
  
                         if(_lastErr)
                         {
@@ -807,10 +810,10 @@ retry:
                             printf("\n io error , aborting sync\n");
                             return 0;
                          }
-
                 }
 
-                *stream=read8i();
+				*stream = hnt;
+
                 // Case 1 : assume we are still in the same packet
                 if(_pesBufferIndex>=5)
                 {
@@ -827,7 +830,7 @@ retry:
                                  { // previous Packet which len is very shoty
                                    // Ignore
                                    _pesBufferIndex=0;
-                                   printf("Ignoring too short packet");
+                                   printf("Ignoring too short packet\n");
                                    goto retry;
                                  }
                                  left=_oldPesLen-left;
