@@ -30,7 +30,6 @@
 
 #include "ADM_codecs/ADM_codec.h"
 #include "ADM_codecs/ADM_ffmp43.h"
-#include "ADM_codecs/ADM_png.h"
 #include "ADM_toolkit/toolkit.hxx"
 #include "ADM_toolkit/bitmap.h"
 #include "ADM_editor/ADM_edit.hxx"
@@ -113,18 +112,19 @@ ADMImage *createImageFromFile_jpeg(const char *filename)
 
 		//Retrieve width & height
 		//_______________________
-		    uint16_t tag = 0, count = 0, off;
+		    uint16_t tag = 0, off;
 
 		    
 		    fseek(fd, 0, SEEK_SET);
 		    read16(fd);	// skip jpeg ffd8
-		    while (count < 10 && tag != 0xFFC0) 
+		    while (!feof(fd) && tag != 0xFFC0) 
 		    {
 
 		    	tag = read16(fd);
 		    	if ((tag >> 8) != 0xff) 
 		    	{
 		    		printf("[imageLoader]invalid jpeg tag found (%x)\n", tag);
+					continue;
 		    	}
 		    	if (tag == 0xFFC0) 
 		    	{
@@ -134,6 +134,7 @@ ADMImage *createImageFromFile_jpeg(const char *filename)
 		    		w = read16(fd);
 	                if(w&1) w++;
 	                if(h&1) h++;
+					break;
 		    	} 
 		    	else 
 		    	{
@@ -146,11 +147,10 @@ ADMImage *createImageFromFile_jpeg(const char *filename)
 		    		}
 		    		fseek(fd, off - 2, SEEK_CUR);
 		    	}
-			count++;
 		    }
 		    if (tag != 0xffc0) 
 		    {
-		    	printf("[imageLoader]Cannot fint start of frame\n");
+		    	printf("[imageLoader]Cannot find start of frame\n");
 				fclose(fd);
 				return NULL;
 		    }
@@ -338,7 +338,7 @@ ADMImage *createImageFromFile_png(const char *filename)
     
  	   ADMImage tmpImage(w,h,1);
     	// Decode PNG
-    	decoderPng decoder(w,h);
+    	decoderFFPng decoder(w,h);
     	ADMCompressedImage bin;
     	bin.data=data;
     	bin.dataLength=size; // This is more than actually, but who cares...
@@ -346,9 +346,14 @@ ADMImage *createImageFromFile_png(const char *filename)
     	decoder.uncompress (&bin, &tmpImage);
     	
     	ADMImage *image=new ADMImage(w,h);
-    	COL_RGB24_to_YV12( w, h,tmpImage._planes[0],image->data);
-    
+
+		COL_Generic2YV12 *convert = new COL_Generic2YV12(tmpImage._width, tmpImage._height, tmpImage._colorspace);
+
+		convert->transform(tmpImage._planes, tmpImage._planeStride, image->data);
+
+    	delete convert;
     	delete [] data;
+
     	return image;		
 }
 /**
