@@ -40,6 +40,7 @@
 #include "ADM_video/ADM_genvideo.hxx"
 #include "ADM_video/ADM_vidEqualizer.h"
 #include "ADM_assert.h"
+#include "DIA_flyEqualiser.h"
 
 extern "C" {
 #include "ADM_libraries/ADM_lavcodec/avcodec.h"
@@ -427,6 +428,10 @@ gfloat g;
         //gtk_curve_set_curve_type(GTK_CURVE(WID(curve1)),GTK_CURVE_TYPE_LINEAR);
 
 }
+
+uint8_t flyEqualiser::upload(void) {}
+uint8_t flyEqualiser::download(void) {}
+
 GtkWidget*
 create_dialog1 (void)
 {
@@ -461,7 +466,7 @@ create_dialog1 (void)
   gtk_widget_show (drawingarea1);
   gtk_box_pack_start (GTK_BOX (vbox1), drawingarea1, TRUE, TRUE, 0);
 
-  gui_scale = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (0, 0, 100, 1, 10, 10)));
+  gui_scale = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (0, 0, 100, 1, 10, 0)));
   gtk_widget_show (gui_scale);
   gtk_box_pack_start (GTK_BOX (vbox1), gui_scale, TRUE, TRUE, 0);
 
