@@ -23,11 +23,7 @@
 #include "ADM_assert.h"
 
 #include "ADM_video/ADM_genvideo.hxx"
-#include "ADM_video/ADM_vidCNR2_param.h"
-#include "ADM_video/ADM_vidColorYuv_param.h"
 #include "ADM_video/ADM_vidEqualizer.h"
-#include "ADM_video/ADM_vidMPdelogo.h"
-    
 #include "ADM_encoder/ADM_vidEncode.hxx"
 #include "ADM_audiofilter/audioencoder.h"
 
@@ -36,11 +32,6 @@
 int  DIA_getXvidCompressParams(COMPRESSION_MODE * mode, uint32_t * qz,
 		      uint32_t * br,uint32_t *fsize,xvidEncParam *param){return 0;}
 #endif
-int     DIA_coloryuv(COLOR_YUV_PARAM *param){return 0;}
-uint8_t DIA_cnr2(CNR2Param *param){return 0;}
-uint8_t DIA_getEqualizer(EqualizerParam *param, ADMImage *image){return 0;}
-uint8_t DIA_getEqualizer(EqualizerParam *param, AVDMGenericVideoStream *in){return 0;}
-uint8_t DIA_getMPdelogo(MPDELOGO_PARAM *param,AVDMGenericVideoStream *in){return 0;}
 uint8_t DIA_videoCodec (SelectCodecType * codec){return 0;}
 uint8_t DIA_audioCodec( AUDIOENCODER *codec ) {return 0;}
 uint8_t DIA_quota(char *) {return 0;}
@@ -48,8 +39,6 @@ uint8_t DIA_RecentFiles( char **name ){return 0;}
 uint8_t initFileSelector(void){return 0;}
 uint8_t initGUI( void ) {return 1;}
 void destroyGUI(void) {}
-int DIA_colorSel(uint8_t *r, uint8_t *g, uint8_t *b) {return 0;}
-uint8_t DIA_glyphEdit(void){ return 0;};
 int32_t UI_readJog(void) {return 0;}
 struct THRESHOLD_PARAM;
 struct ADMVideoThreshold;
