@@ -17,6 +17,7 @@
 
 #include "ui_license.h"
 #include "default.h"
+#include "../ADM_toolkit/qtToolkit.h"
 
 class Ui_licenseWindow : public QDialog
 {
@@ -26,14 +27,14 @@ private:
 	Ui_licenseDialog ui;
 
 public:
-	Ui_licenseWindow();
+	Ui_licenseWindow(QWidget *parent);
 };
 
-Ui_licenseWindow::Ui_licenseWindow()
+Ui_licenseWindow::Ui_licenseWindow(QWidget *parent) : QDialog(parent)
 {
 	ui.setupUi(this);
 
-	ui.licenseTextEdit->setHtml(QT_TR_NOOP("<!DOCTYPE html PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">" \
+	ui.licenseTextEdit->setHtml(QString::fromUtf8(QT_TR_NOOP("<!DOCTYPE html PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">" \
 	"" \
 	"<html>" \
 	"<head>" \
@@ -704,14 +705,16 @@ Ui_licenseWindow::Ui_licenseWindow()
 	"    <span style='font-size:10.0pt; font-family:Arial'> </span></p>" \
 	"  </div>" \
 	"</body>" \
-	"</html>"));
+	"</html>")));
 }
 
 uint8_t DIA_license(void)
 {
-	Ui_licenseWindow dialog;
+	Ui_licenseWindow dialog(qtLastRegisteredDialog());
 
+	qtRegisterDialog(&dialog);
 	dialog.exec();
+	qtUnregisterDialog(&dialog);
 
 	return 1;
 }
