@@ -31,6 +31,7 @@
 #include "default.h"
 #include "ADM_commonUI/DIA_factory.h"
 #include "ADM_assert.h"
+#include "dialogFactoryQt4.h"
 
 extern const char *shortkey(const char *);
 
@@ -51,11 +52,11 @@ class  ADM_Qbitrate : public QWidget
         COMPRES_PARAMS  *compress;
 		uint32_t		_minQ;
         uint32_t        maxQ;
-        ADM_Qbitrate(QWidget *z,COMPRES_PARAMS *p,uint32_t minQ, uint32_t mq,QGridLayout *layout,int line) : QWidget(z) 
+        ADM_Qbitrate(COMPRES_PARAMS *p,uint32_t minQ, uint32_t mq,QGridLayout *layout,int line)
         {
           
            compress=p;
-           combo=new QComboBox(z);
+           combo=new QComboBox();
            
 		   _minQ=minQ;
            maxQ=mq;
@@ -65,40 +66,45 @@ class  ADM_Qbitrate : public QWidget
 						index++;}
   
   add(CBR,CBR,QT_TR_NOOP("Constant Bitrate"));
-  add(CQ,CQ,QT_TR_NOOP("Constant Quality"));
-  add(SAME,SAME,QT_TR_NOOP("Same Quantizer as Input"));
-  add(AQ,AQ,QT_TR_NOOP("Average Quantizer"));
+  add(CQ,CQ,QT_TR_NOOP("Constant Quantiser"));
+  add(SAME,SAME,QT_TR_NOOP("Same Quantiser as Input"));
+  add(AQ,AQ,QT_TR_NOOP("Constant Rate Factor"));
   add(2PASS,2PASS,QT_TR_NOOP("Two Pass - Video Size"));
   add(2PASS_BR,2PASS_BITRATE,QT_TR_NOOP("Two Pass - Average Bitrate"));
   
-           combo->show();
-           
-           text1=new QLabel( QString::fromUtf8(QT_TR_NOOP("Encoding mode")),z);
+           text1=new QLabel( QString::fromUtf8(QT_TR_NOOP("Encoding mode")));
           text1->setBuddy(combo);
-          text1->show();
-          
-           box=new QSpinBox(z);
-           box->show();
-           
-           text2=new QLabel( QString::fromUtf8(QT_TR_NOOP("Bitrate")),z);
+
+           box=new QSpinBox();
+
+           text2=new QLabel( QString::fromUtf8(QT_TR_NOOP("Bitrate")));
            text2->setBuddy(combo);
-          
-          
+
+		   QHBoxLayout *hboxLayout = new QHBoxLayout();
+		   QHBoxLayout *hboxLayout2 = new QHBoxLayout();
+		   QSpacerItem *spacer = new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);
+		   QSpacerItem *spacer2 = new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);
+
+		   hboxLayout->addWidget(combo);
+		   hboxLayout->addItem(spacer);
+
           layout->addWidget(text1,line,0);
-          layout->addWidget(combo,line,1);
-          
+		  layout->addItem(hboxLayout,line,1);
+
+		  hboxLayout2->addWidget(box);
+		  hboxLayout2->addItem(spacer2);
+
           layout->addWidget(text2,line+1,0);
-          layout->addWidget(box,line+1,1);
-       
-       
+          layout->addItem(hboxLayout2,line+1,1);
+
           if(set!=-1) 
           {
         	  	combo->setCurrentIndex(set);
         	  	comboChanged(set);
           }
-          QObject::connect(combo, SIGNAL(currentIndexChanged(int )), this, SLOT(comboChanged(int )));
-          
-          
+          connect(combo, SIGNAL(currentIndexChanged(int )), this, SLOT(comboChanged(int )));
+
+
         }
         virtual ~ADM_Qbitrate() ;
         void readBack(void);
@@ -144,7 +150,7 @@ void ADM_Qbitrate::readBack(void)
     case COMPRESS_2PASS: Mx(COMPRESS_2PASS);Vx(finalsize);break;
     case COMPRESS_2PASS_BITRATE: Mx(COMPRESS_2PASS_BITRATE);Vx(avg_bitrate);break;
     case COMPRESS_SAME: Mx(COMPRESS_SAME);break;
-    case COMPRESS_AQ: Mx(COMPRESS_AQ);break;
+    case COMPRESS_AQ: Mx(COMPRESS_AQ);Vx(qz);break;
     default :
           ADM_assert(0);
   }
@@ -225,22 +231,13 @@ void diaElemBitrate::setMaxQz(uint32_t qz)
   maxQ=qz; 
 }
 
-diaElemBitrate::~diaElemBitrate()
-{
-  ADM_assert(myWidget);
-#if 0 // Automatically deleted as it is a child of main dialog
-  ADM_Qbitrate *z=(ADM_Qbitrate *)myWidget;
-  
-  if(z) delete z;
+diaElemBitrate::~diaElemBitrate() {};
 
-  myWidget=NULL;
-#endif
-}
 void diaElemBitrate::setMe(void *dialog, void *opaque,uint32_t line)
 {
   QGridLayout *layout=(QGridLayout*) opaque;
   
-  ADM_Qbitrate *b=new ADM_Qbitrate( (QWidget *)dialog,(COMPRES_PARAMS *)&copy,minQ,maxQ,layout,line);
+  ADM_Qbitrate *b=new ADM_Qbitrate((COMPRES_PARAMS *)&copy,minQ,maxQ,layout,line);
   myWidget=(void *)b;
   
 }
@@ -250,5 +247,7 @@ void diaElemBitrate::getMe(void)
   memcpy(param,&copy,sizeof(copy));
 }
 
+int diaElemBitrate::getRequiredLayout(void) { return FAC_QT_GRIDLAYOUT; }
+
 //EOF
 
