@@ -29,12 +29,14 @@
 #include <sys/stat.h>
 #include <unistd.h>
 #include <vector>
+#include <QtGui>
 
 #define Ui_Dialog Ui_mainFilterDialog
 #include "ui_mainfilter.h"
 #undef Ui_Dialog
-#include "QStringListModel" 
-#include "QColor" 
+
+#include "Q_seekablePreview.h"
+
 #include "default.h"
 #include "ADM_toolkit/filesel.h"
 
@@ -52,6 +54,8 @@
 #include "ADM_video/ADM_vidPartial.h"
 #include "ADM_filter/vidVCD.h"
 #include "ADM_userInterfaces/ADM_commonUI/DIA_factory.h"
+#include "../ADM_toolkit/qtToolkit.h"
+
 /*******************************************************/
 #define NB_TREE 8
 #define myFg 0xFF
@@ -62,6 +66,7 @@ static int max=0;
 #define EXTERNAL_FILTER_BASE  2000
 #define ACTIVE_FILTER_BASE    3000
 /******************************************************/
+extern QWidget *QuiMainWindows;
 extern FILTER videofilters[MAX_FILTER];
 extern uint32_t nb_active_filter;
 extern std::vector <FILTER_ENTRY> allfilters;
@@ -69,14 +74,86 @@ extern std::vector <FILTER_ENTRY> allfilters;
 extern const char  *filterGetNameFromTag(VF_FILTERS tag);
 extern ADM_Composer *video_body;
 extern AVDMGenericVideoStream *filterCreateFromTag(VF_FILTERS tag,CONFcouple *conf, AVDMGenericVideoStream *in) ;
+extern uint32_t curframe;
 /*******************************************************/
+
+class FilterItemEventFilter : public QObject
+{
+	Q_OBJECT
+
+protected:
+	bool eventFilter(QObject *object, QEvent *event) 
+	{
+		QAbstractItemView *view = qobject_cast<QAbstractItemView*>(parent());
+
+		if (event->type() == QEvent::KeyPress || event->type() == QEvent::MouseButtonPress)
+		{
+			QCoreApplication::sendEvent(view, event);
+
+			return true;
+		}
+		else if (event->type() == QEvent::FocusIn)
+		{
+			view->setFocus();
+
+			return true;
+		}
+		else
+			return QObject::eventFilter(object, event);
+	};
+
+public:
+	FilterItemEventFilter(QWidget *parent = 0) : QObject(parent) {};
+};
+
+class FilterItemDelegate : public QItemDelegate
+{
+	Q_OBJECT
+
+private:
+	FilterItemEventFilter *filter;
+
+public:
+	FilterItemDelegate(QWidget *parent = 0) : QItemDelegate(parent)
+	{
+		filter = new FilterItemEventFilter(parent);
+	};
+
+	void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
+	{
+		QAbstractItemView *view = qobject_cast<QAbstractItemView*>(parent());
+		QLabel *label;
+
+		if (view->indexWidget(index) == 0)
+		{
+			label = new QLabel();
+
+			label->installEventFilter(filter);
+			label->setAutoFillBackground(true);
+			label->setFocusPolicy(Qt::TabFocus);
+			label->setText(index.data().toString());
+			view->setIndexWidget(index, label);
+		}
+
+		label = (QLabel*)view->indexWidget(index);
+
+		if (option.state & QStyle::State_Selected)
+			if (option.state & QStyle::State_HasFocus)
+				label->setBackgroundRole(QPalette::Highlight);
+			else
+				label->setBackgroundRole(QPalette::Window);
+		else
+			label->setBackgroundRole(QPalette::Base);
+	};
+};
+
 class filtermainWindow : public QDialog
 {
      Q_OBJECT
 
  public:
-     filtermainWindow();
- //    virtual ~filtermainWindow();
+     filtermainWindow(QWidget *parent);
+	 ~filtermainWindow();
      void             buildActiveFilterList(void);
      Ui_mainFilterDialog ui;
      
@@ -98,18 +175,68 @@ class filtermainWindow : public QDialog
         void remove(bool b);
         void configure(bool b);
         void partial(bool b);
+		void loadScript(bool b);
+		void saveScript(bool b);
         void activeDoubleClick( QListWidgetItem  *item);
+		void activeItemChanged(QListWidgetItem *current, QListWidgetItem *previous);
         void allDoubleClick( QListWidgetItem  *item);
-	void filterFamilyClick(QListWidgetItem *item);
-	void filterFamilyClick(int  item);
- private slots:
+		void filterFamilyItemChanged(QListWidgetItem *current, QListWidgetItem *previous);
+		void preview(bool b);
+		void closePreview();
+
  private:
+		uint32_t previewFrameIndex;
+		int previewDialogX, previewDialogY;
+		Ui_seekablePreviewWindow *previewDialog;
+
         int startFilter[NB_TREE];
         int filterSize[NB_TREE];
         void setSelected(int sel);
         void displayFamily(uint32_t family);
         void setupFilters(void);
 };
+
+void filtermainWindow::preview(bool b)
+{
+	QListWidgetItem *item = activeList->currentItem();
+
+	if (!item)
+	{
+		printf("No selection\n");
+		return;
+	}
+
+	int itag = item->type();
+	ADM_assert(itag > ACTIVE_FILTER_BASE);
+	itag -= ACTIVE_FILTER_BASE;
+
+	if (previewDialog)
+		previewDialog->resetVideoStream(videofilters[itag].filter);
+	else
+	{
+		previewDialog = new Ui_seekablePreviewWindow(this, videofilters[itag].filter, previewFrameIndex);
+		connect(previewDialog, SIGNAL(accepted()), this, SLOT(closePreview()));
+
+		if (previewDialogX != INT_MIN)
+			previewDialog->move(previewDialogX, previewDialogY);
+	}
+
+	previewDialog->show();
+}
+
+void filtermainWindow::closePreview()
+{
+	if (previewDialog)
+	{
+		previewFrameIndex = previewDialog->frameIndex();
+		previewDialogX = previewDialog->x();
+		previewDialogY = previewDialog->y();
+
+		delete previewDialog;
+		previewDialog = NULL;
+	}
+}
+
 /**
         \fn     void setSelected(int sel)
         \brief  Set the sel line as selected in the active filter window
@@ -151,12 +278,19 @@ void filtermainWindow::add( bool b)
             delete videofilters[nb_active_filter].filter;
             return;
         }
+
+		bool previewDialogOpen = (previewDialog != NULL);
+
+		closePreview();
         videofilters[nb_active_filter].filter->getCoupledConf (&coup);
         videofilters[nb_active_filter].tag = tag;
         videofilters[nb_active_filter].conf = coup;
         nb_active_filter++;
-        setSelected(nb_active_filter);
-        buildActiveFilterList();
+		buildActiveFilterList();
+        setSelected(nb_active_filter - 1);
+
+		if (previewDialogOpen)
+			preview(true);
    }
 
 }
@@ -174,7 +308,11 @@ void filtermainWindow::remove( bool b)
       printf("No selection\n");
       return;
    }
-    
+
+   bool previewDialogOpen = (previewDialog != NULL);
+
+   closePreview();
+
      int itag=item->type();
      ADM_assert(itag>ACTIVE_FILTER_BASE);
      itag-=ACTIVE_FILTER_BASE;
@@ -209,14 +347,25 @@ void filtermainWindow::remove( bool b)
               else
                   setSelected(nb_active_filter-1);
             }
-  
+
+			if (previewDialogOpen)
+				preview(true);
 }
 #define MAKE_BUTTON(button,call) \
 void filtermainWindow::button( bool b) \
 { \
-    call(); \
-    getFirstVideoFilter (); \
-    buildActiveFilterList ();  \
+    if (call()) \
+	{ \
+		bool previewDialogOpen = (previewDialog != NULL); \
+\
+		closePreview(); \
+		getFirstVideoFilter (); \
+		buildActiveFilterList ();  \
+		setSelected(nb_active_filter - 1); \
+\
+		if (previewDialogOpen) \
+			preview(true); \
+	} \
 }
 MAKE_BUTTON(DVD,setDVD)
 MAKE_BUTTON(VCD,setVCD)
@@ -246,12 +395,21 @@ void filtermainWindow::configure( bool b)
      /**/
      
         if(!videofilters[itag].filter->configure (videofilters[itag - 1].filter)) return;
+
+		bool previewDialogOpen = (previewDialog != NULL);
+
+		closePreview();
+
         /* Recreate chain if needed , config has changed */
         CONFcouple *couple;
         videofilters[itag].filter->getCoupledConf (&couple);
         videofilters[itag].conf = couple;
         getFirstVideoFilter ();
         buildActiveFilterList ();
+		setSelected(itag);
+
+		if (previewDialogOpen)
+			preview(true);
 }
 /**
         \fn     up( bool b)
@@ -274,6 +432,11 @@ void filtermainWindow::up( bool b)
      ADM_assert(itag);
      
      if (itag < 2) return;
+
+	 bool previewDialogOpen = (previewDialog != NULL);
+
+	 closePreview();
+
         // swap action parameter & action parameter -1
         FILTER tmp;
         memcpy (&tmp, &videofilters[itag - 1], sizeof (FILTER));
@@ -283,6 +446,9 @@ void filtermainWindow::up( bool b)
         getFirstVideoFilter ();
         buildActiveFilterList ();
         setSelected(itag-1);
+
+		if (previewDialogOpen)
+			preview(true);
 }
 /**
         \fn     down( bool b)
@@ -306,6 +472,10 @@ void filtermainWindow::down( bool b)
      
     if (((int) itag < (int) (nb_active_filter - 1)) && (itag))
         {
+			bool previewDialogOpen = (previewDialog != NULL);
+
+			closePreview();
+
             // swap action parameter & action parameter -1
             FILTER tmp;
             memcpy (&tmp, &videofilters[itag + 1], sizeof (FILTER));
@@ -315,6 +485,9 @@ void filtermainWindow::down( bool b)
             getFirstVideoFilter ();
             buildActiveFilterList ();
             setSelected(itag+1);
+
+			if (previewDialogOpen)
+				preview(true);
         }
 }
 /**
@@ -322,25 +495,19 @@ void filtermainWindow::down( bool b)
         \brief  Select family among color etc... 
 */
 
-void filtermainWindow::filterFamilyClick(QListWidgetItem *item)
+void filtermainWindow::filterFamilyItemChanged(QListWidgetItem *current, QListWidgetItem *previous)
 {
-    int family= ui.listFilterCategory->currentRow();
-    if(family>=0)
-        displayFamily(family);
-}
-void filtermainWindow::filterFamilyClick(int  m)
-{
-        if(m>=0)
-                displayFamily(m);
+	int family = ui.listFilterCategory->currentRow();
+
+	if(family >= 0)
+		displayFamily(family);
 }
+
 void filtermainWindow::displayFamily(uint32_t family)
 {
   printf("Family :%u\n",family);
   
   availableList->clear();
-  QColor colorgrey;
-  colorgrey.setRgb(myBg,myBg,myBg);
-  QBrush brush(colorgrey);
   QSize sz;
   
   for (uint32_t i = 0; i < filterSize[family]; i++)
@@ -349,21 +516,33 @@ void filtermainWindow::displayFamily(uint32_t family)
 
       if (allfilters[r].viewable==1)
         {
-          QString str; //="<b>";
-          str+=allfilters[r].name;
+			QString str = QString("<b>") + QString::fromUtf8(allfilters[r].name) + QString("</b><br>\n<small>") + QString::fromUtf8(allfilters[r].description) + QString("</small>");
          
           QListWidgetItem *item;
           if(family==NB_TREE-1)
                 item=new QListWidgetItem(str,availableList,EXTERNAL_FILTER_BASE+i);
           else
                 item=new QListWidgetItem(str,availableList,ALL_FILTER_BASE+r);
-          item->setToolTip(allfilters[r].description);
-          if(i&1) item->setBackground(brush);
+		  item->setToolTip(QString::fromUtf8(allfilters[r].description));
           availableList->addItem(item);
-          
         }
      }
-   
+
+  if (filterSize[family])
+	  availableList->setCurrentRow(0);
+}
+
+void filtermainWindow::activeItemChanged(QListWidgetItem *current, QListWidgetItem *previous)
+{
+	if (previewDialog && previewDialog->isVisible())
+	{
+		int itag = current->type();
+
+		ADM_assert(itag > ACTIVE_FILTER_BASE);
+		itag -= ACTIVE_FILTER_BASE;
+
+		previewDialog->resetVideoStream(videofilters[itag].filter);
+	}
 }
 
 /**
@@ -419,6 +598,10 @@ void filtermainWindow::partial( bool b)
                                       conf);
         if(replace->configure (videofilters[itag - 1].filter))
         {
+			bool previewDialogOpen = (previewDialog != NULL);
+
+			closePreview();
+
             delete videofilters[itag].filter;
             if (conf) delete conf;
             videofilters[itag].filter = replace;
@@ -426,10 +609,49 @@ void filtermainWindow::partial( bool b)
             videofilters[itag].conf = conf;
             videofilters[itag].tag = VF_PARTIAL;
             getFirstVideoFilter ();
-            buildActiveFilterList ();   
+            buildActiveFilterList ();
+			setSelected(itag);
+
+			if (previewDialogOpen)
+				preview(true);
         }
         else delete replace;
 }
+
+void filtermainWindow::loadScript(bool)
+{
+	bool previewDialogOpen = (previewDialog != NULL);
+
+	closePreview();
+
+#ifdef USE_LIBXML2
+	GUI_FileSelRead (QT_TR_NOOP("Load set of filters"), filterLoadXml);
+#else
+	GUI_FileSelRead (QT_TR_NOOP("Load set of filters"), filterLoad);
+#endif
+
+	getFirstVideoFilter ();
+	buildActiveFilterList ();
+	setSelected(nb_active_filter - 1);
+
+	if (previewDialogOpen)
+		preview(true);
+}
+
+void filtermainWindow::saveScript(bool)
+{
+	if (nb_active_filter < 2)
+	{
+		GUI_Error_HIG (QT_TR_NOOP("Nothing to save"), NULL);
+	}
+	else
+#ifdef USE_LIBXML2
+		GUI_FileSelWrite(QT_TR_NOOP("Save set of filters"), filterSaveXml);
+#else
+		GUI_FileSelWrite(QT_TR_NOOP("Save set of filters"), filterSave);
+#endif
+}
+
 /**
         \fn setup
         \brief Prepare 
@@ -472,66 +694,85 @@ void filtermainWindow::setupFilters(void)
 */
 void filtermainWindow::buildActiveFilterList(void)
 {
-  VF_FILTERS fil;
-  
-  
-  activeList->clear();
-  QColor colorGrey,colorWhite;
-  colorGrey.setRgb(myBg,myBg,myBg);
-  colorWhite.setRgb(myFg,myFg,myFg);
-  QBrush brush(colorGrey);
-  QBrush brushW(colorWhite);
+	activeList->clear();
 
-  for (uint32_t i = 1; i < nb_active_filter; i++)
-    {
-                QString str;
-                fil=videofilters[i].tag;
+	for (uint32_t i = 1; i < nb_active_filter; i++)
+	{
+		const char *name = filterGetNameFromTag(videofilters[i].tag);
+		const char *conf = videofilters[i].filter->printConf ();
+		int namelen = strlen (name);
 
-                 str =filterGetNameFromTag(fil);
-                 str+= videofilters[i].filter->printConf ();
-                 QListWidgetItem *item=new QListWidgetItem(str,activeList,ACTIVE_FILTER_BASE+i);
-                 if(i&1) item->setBackground(brush);
-                        else item->setBackground(brushW);
-                 activeList->addItem(item);
-    }
-    
+		while (*conf == ' ')
+			++conf;
 
+		if (strncasecmp (name, conf, namelen) == 0)
+		{
+			conf += namelen;
+			while (*conf == ' ' || *conf == ':')
+				++conf;
+		}
+
+		QString str = QString("<b>") + QString::fromUtf8(name) + QString("</b><br>\n<small>") + QString::fromUtf8(conf) + QString("</small>");
+		QListWidgetItem *item=new QListWidgetItem(str,activeList,ACTIVE_FILTER_BASE+i);
+		activeList->addItem(item);
+	}
 }
   /**
   */
-filtermainWindow::filtermainWindow()     : QDialog()
+filtermainWindow::filtermainWindow(QWidget* parent) : QDialog(parent)
  {
         memset( startFilter,0,sizeof(int)*NB_TREE);
         memset( filterSize,0,sizeof(int)*NB_TREE);
  
     ui.setupUi(this);
-    setupFilters();  
-      
+    setupFilters();
+
+	previewDialog = NULL;
+	previewDialogX = INT_MIN;
+	previewDialogY = INT_MIN;
+	previewFrameIndex = curframe;
+
     availableList=ui.listWidgetAvailable;
     activeList=ui.listWidgetActive;
-    connect(ui.listFilterCategory,SIGNAL(itemDoubleClicked(QListWidgetItem *)),
-                this,SLOT(filterFamilyClick(QListWidgetItem *)));
-    connect(ui.listFilterCategory,SIGNAL(itemClicked(QListWidgetItem *)),
-                this,SLOT(filterFamilyClick(QListWidgetItem *)));
+
+	ui.buttonBox->button(QDialogButtonBox::Close)->setDefault(true);
+	ui.buttonBox->addButton(ui.pushButtonPreview, QDialogButtonBox::ActionRole);
+
+	connect(ui.listFilterCategory, SIGNAL(currentItemChanged(QListWidgetItem*, QListWidgetItem*)), this, SLOT(filterFamilyItemChanged(QListWidgetItem*, QListWidgetItem *)));
 
     connect(activeList,SIGNAL(itemDoubleClicked(QListWidgetItem *)),this,SLOT(activeDoubleClick(QListWidgetItem *)));
+	connect(activeList, SIGNAL(currentItemChanged(QListWidgetItem*, QListWidgetItem*)), this, SLOT(activeItemChanged(QListWidgetItem*, QListWidgetItem*)));
     connect(availableList,SIGNAL(itemDoubleClicked(QListWidgetItem *)),this,SLOT(allDoubleClick(QListWidgetItem *)));
-    
+
     connect((ui.toolButtonConfigure),SIGNAL(clicked(bool)),this,SLOT(configure(bool)));
     connect((ui.toolButtonAdd),SIGNAL(clicked(bool)),this,SLOT(add(bool)));
     connect((ui.pushButtonRemove),SIGNAL(clicked(bool)),this,SLOT(remove(bool)));
     connect((ui.toolButtonUp),SIGNAL(clicked(bool)),this,SLOT(up(bool)));
     connect((ui.toolButtonDown),SIGNAL(clicked(bool)),this,SLOT(down(bool)));
     connect((ui.toolButtonPartial),SIGNAL(clicked(bool)),this,SLOT(partial(bool)));
-    connect(ui.buttonClose, SIGNAL(clicked(bool)), this, SLOT(accept()));
+
+	connect(ui.toolButtonLoad, SIGNAL(clicked(bool)), this, SLOT(loadScript(bool)));
+	connect(ui.toolButtonSaveScript, SIGNAL(clicked(bool)), this, SLOT(saveScript(bool)));
+
     connect(ui.pushButtonDVD, SIGNAL(clicked(bool)), this, SLOT(DVD(bool)));
     connect(ui.pushButtonVCD, SIGNAL(clicked(bool)), this, SLOT(VCD(bool)));
     connect(ui.pushButtonSVCD, SIGNAL(clicked(bool)), this, SLOT(SVCD(bool)));
     connect(ui.pushButtonHalfDVD, SIGNAL(clicked(bool)), this, SLOT(halfD1(bool)));
-   
+	connect(ui.pushButtonPreview, SIGNAL(clicked(bool)), this, SLOT(preview(bool)));
+
+	activeList->setItemDelegate(new FilterItemDelegate(activeList));
+	availableList->setItemDelegate(new FilterItemDelegate(availableList));
+
     displayFamily(0);
-    buildActiveFilterList(); 
+    buildActiveFilterList();
+	setSelected(nb_active_filter - 1);
  }
+
+filtermainWindow::~filtermainWindow()
+{
+	if (previewDialog)
+		delete previewDialog;
+}
 /*******************************************************/
 
 int GUI_handleVFilter(void);
@@ -545,10 +786,13 @@ static void updateFilterList (filtermainWindow *dialog);
 */
 int GUI_handleVFilter(void)
 {
-        filtermainWindow dialog;
-        if(QDialog::Accepted==dialog.exec())
-        {
-        }
+	filtermainWindow dialog(qtLastRegisteredDialog());
+	qtRegisterDialog(&dialog);
+
+	dialog.exec();
+
+	qtUnregisterDialog(&dialog);
+
 	return 0;
 }
 /** 
