@@ -31,6 +31,8 @@
 #include <QtGui/QKeyEvent>
 #include <QtGui/QValidator>
 
+#include "T_thumbSlider.h"
+#include "../ADM_toolkit/qtToolkit.h"
 #include "ADM_qslider.h"
 #include "default.h"
 #include "ADM_osSupport/ADM_misc.h"
@@ -40,6 +42,8 @@
 #include "ADM_toolkit/filesel.h"
 #include "prefs.h"
 #include "avi_vars.h"
+#include "../ADM_commonUI/GUI_render.h"
+#include "gtkgui.h"
 
 extern int global_argc;
 extern char **global_argv;
@@ -122,6 +126,9 @@ public:
 	
 	Ui_MainWindow ui;
 
+protected:
+	ThumbSlider *thumbSlider;
+
 public slots:
 	void timeChanged(int);
 	void buttonPressed(void);
@@ -174,6 +181,14 @@ public slots:
 		SliderIsShifted = 0;
 	}
 
+	void thumbSlider_valueEmitted(int value)
+	{
+		if (value > 0)
+			nextIntraFrame();
+		else
+			previousIntraFrame();
+	}
+
 	void volumeChange( int u )
 	{
 #ifdef HAVE_AUDIO
@@ -232,11 +247,13 @@ protected:
 	void mousePressEvent(QMouseEvent* event);
 	void dragEnterEvent(QDragEnterEvent *event);
 	void dropEvent(QDropEvent *event);
+	void closeEvent(QCloseEvent *event);
 };
 
 
 MainWindow::MainWindow() : QMainWindow()
 {
+	qtRegisterDialog(this);
 	ui.setupUi(this);
 
 	this->setStatusBar(0);
@@ -287,10 +304,16 @@ MainWindow::MainWindow() : QMainWindow()
 	slider=ui.horizontalSlider;
 	slider->setMinimum(0);
 	slider->setMaximum(1000000000);
+	slider->setPageStep(10000000);
 	connect( slider,SIGNAL(valueChanged(int)),this,SLOT(sliderValueChanged(int)));
 	connect( slider,SIGNAL(sliderMoved(int)),this,SLOT(sliderMoved(int)));
 	connect( slider,SIGNAL(sliderReleased()),this,SLOT(sliderReleased()));
 
+	// Thumb slider
+	ui.sliderPlaceHolder->installEventFilter(this);
+	thumbSlider = new ThumbSlider(ui.sliderPlaceHolder);
+	connect(thumbSlider, SIGNAL(valueEmitted(int)), this, SLOT(thumbSlider_valueEmitted(int)));
+
 	// Volume slider
 	QSlider *volSlider=ui.horizontalSlider_2;
 	volSlider->setMinimum(0);
@@ -465,6 +488,16 @@ bool MainWindow::eventFilter(QObject* watched, QEvent* event)
 				if (!UI_readCurTime(hh, mm, ss, ms))
 					UI_updateTimeCount(currentFrame, currentFps);
 			}
+
+			break;
+		case QEvent::Resize:
+			if (watched == ui.sliderPlaceHolder)
+			{
+				thumbSlider->resize(ui.sliderPlaceHolder->width(), 16);
+				thumbSlider->move(0, (ui.sliderPlaceHolder->height() - thumbSlider->height()) / 2);
+			}
+
+			break;
 	}
 
 	return QObject::eventFilter(watched, event);
@@ -577,9 +610,16 @@ void MainWindow::buildCustomMenu(void)
 	printf("Custom menu built\n");
 }
 
+void MainWindow::closeEvent(QCloseEvent *event)
+{
+	HandleAction(ACT_Exit);
+}
+
 MainWindow::~MainWindow()
 {
+	delete thumbSlider;
 	clearCustomMenu();
+	renderDestroy();
 }
 
 int UI_Init(int nargc,char **nargv)
@@ -765,7 +805,7 @@ void setupMenus(void)
 	printf("Found %d format(s)\n",nbFormat);
 	for(uint32_t i=0;i<nbFormat;i++)
 	{
-		WIDGET(comboBoxFormat)->addItem(QT_TR_NOOP(ADM_allOutputFormat[i].text));	
+		WIDGET(comboBoxFormat)->addItem(QString::fromUtf8(ADM_allOutputFormat[i].text));	
 	}
 
 }
@@ -820,6 +860,15 @@ int UI_readCurTime(uint16_t &hh, uint16_t &mm, uint16_t &ss, uint16_t &ms)
 	return success;
 }
 
+void UI_iconify( void )
+{
+	QuiMainWindows->hide();
+}
+void UI_deiconify( void )
+{
+	QuiMainWindows->showNormal();
+}
+
 void UI_purge( void )
 {
 	QCoreApplication::processEvents ();
@@ -874,7 +923,7 @@ void UI_setFrameType( uint32_t frametype,uint32_t qp)
 
 	}
 	sprintf(string,QT_TR_NOOP("%c (%02d)"),c,qp);
-	WIDGET(label_8)->setText(string);	
+	WIDGET(label_8)->setText(QString::fromUtf8(string));
 
 }
 
@@ -1054,5 +1103,24 @@ uint8_t UI_setTimeShift(int onoff,int value)
 	return 1;
 }
 
+void UI_setZoomMode(renderZoom zoom)
+{
+	switch (zoom)
+	{
+		case ZOOM_1_4:
+			WIDGET(actionZoom_1_4)->setChecked(true);
+			break;
+		case ZOOM_1_2:
+			WIDGET(actionZoom_1_2)->setChecked(true);
+			break;
+		case ZOOM_1_1:
+			WIDGET(actionZoom_1_1)->setChecked(true);
+			break;
+		case ZOOM_2:
+			WIDGET(actionZoom_2_1)->setChecked(true);
+			break;
+	}
+}
+
 //********************************************
 //EOF
