@@ -24,44 +24,83 @@
 #include <time.h>
 #include <sys/time.h>
 
-#include <QtCore/QVariant>
-#include <QtGui/QAction>
-#include <QtGui/QApplication>
-#include <QtGui/QButtonGroup>
-#include <QtGui/QFrame>
-#include <QtGui/QGraphicsView>
-#include <QtGui/QSlider>
-#include <QMessageBox>
-#include <QPainter>
-#include <QImage>
+#include <QtGui>
+
 /* Probably on unix/X11 ..*/
 #ifdef __APPLE__
 #include <Carbon/Carbon.h>
 #elif !defined(ADM_WIN32)
 #include <QX11Info>
 #endif
-#include "avio.hxx"
 
-#include "ADM_colorspace/ADM_rgb.h"
+#include "default.h"
 #include "GUI_render.h"
 #include "GUI_accelRender.h"
-#include "prefs.h"
-#include "ADM_assert.h"
-#include "ui_gui2.h"
-    
-void UI_QT4VideoWidget(QFrame *host);
+#include "ADM_video/ADM_genvideo.hxx"
+#include "Q_preview.h"
+#include "gui_action.hxx"
+
 static QFrame *hostFrame=NULL;
 static AccelRender *accelRender=NULL;
 static uint8_t *lastImage=NULL;
 extern QWidget *QuiMainWindows;
  ColYuvRgb rgbConverter(640,480,1);
 extern void UI_purge( void );
+extern void UI_setCurrentPreview(int ne);
+extern uint8_t UI_getPhysicalScreenSize(void* window, uint32_t *w, uint32_t *h);
+extern void UI_setZoomMode(renderZoom zoom);
+
+static Ui_previewWindow *previewWindow = NULL;
+
+class PreviewEventReceiver : public QObject
+{
+	Q_OBJECT
+
+public slots:
+	void previewClose()
+	{
+		UI_setCurrentPreview(0);
+		HandleAction(ACT_PreviewChanged);
+	};
+};
+
+static PreviewEventReceiver *eventReceiver = NULL;
+
+void DIA_previewInit(uint32_t width, uint32_t height)
+{
+	eventReceiver = new PreviewEventReceiver;
+	previewWindow = new Ui_previewWindow(QuiMainWindows, width, height);
+	QObject::connect(previewWindow, SIGNAL(rejected()), eventReceiver, SLOT(previewClose()));
+	previewWindow->show();
+}
+
+uint8_t DIA_previewStillAlive(void)
+{
+	return (previewWindow != NULL);
+}
+
+uint8_t DIA_previewUpdate(uint8_t *buffer)
+{
+	if (previewWindow)
+	{
+		previewWindow->update(buffer);
+
+		return 1;
+	}
+
+	return 0;
+}
+
+void DIA_previewEnd(void)
+{
+	if (previewWindow)
+	{
+		delete previewWindow;
+		previewWindow = NULL;
+		delete eventReceiver;
+	}
+}
 
-void DIA_previewInit(uint32_t width, uint32_t height) {}
-uint8_t DIA_previewUpdate(uint8_t *data) {return 1;}
-void DIA_previewEnd(void) {}
-uint8_t DIA_previewStillAlive(void) {return 1;}
-uint8_t	DIA_filterPreview(const char *captionText, AVDMGenericVideoStream *videoStream, uint32_t frame) {}
 
 //****************************************************************************************************
 /*
@@ -72,51 +111,65 @@ uint8_t	DIA_filterPreview(const char *captionText, AVDMGenericVideoStream *video
 */
 static uint8_t *rgbDataBuffer=NULL;
 static uint32_t displayW=0,displayH=0;
+
 //****************************************************************************************************
 /*
   This is the class that will display the video images.
   It is a base QWidget where the image will be put by painter.
 
 */
+int paintEngineType = -1;
+
 class  ADM_Qvideo : public QWidget
 {
-     Q_OBJECT
+	Q_OBJECT
     
-  signals:
-        
-        
-   public slots:
-        
-  public:
-        ADM_Qvideo(QWidget *z) : QWidget(z) 
-        {
-          
-        }
-        ~ADM_Qvideo() {};
-        /**
-            \fn paintEvent( QPaintEvent *ev))
-            \brief Repaint our "video" widget, ignore when accelRender is on
-        */
-        void paintEvent(QPaintEvent *ev)
-        {
-          if(!displayW || !displayH || !rgbDataBuffer || accelRender)
-            return ;
+public:
+	ADM_Qvideo(QWidget *z) : QWidget(z)
+	{
+#if QT_VERSION >= 0x040400
+		setAttribute(Qt::WA_MSWindowsUseDirect3D, true);
+#endif
+	};
 
-          if(accelRender) 
-          {
-            if(lastImage)
-            {
-              accelRender->display(lastImage,displayW,displayH);
-            }
-          }else
-          {
-            QImage image(rgbDataBuffer,displayW,displayH,QImage::Format_RGB32);
-              QPainter painter(this);
-              painter.drawImage(QPoint(0,0),image);
-              painter.end();
-          }
-        }
+	~ADM_Qvideo() {};
+
+	/**
+		\fn paintEvent( QPaintEvent *ev))
+		\brief Repaint our "video" widget, ignore when accelRender is on
+	*/
+	void paintEvent(QPaintEvent *ev)
+	{
+		if (paintEngineType == -1)
+		{
+			QPainter painter(this);
+
+			if (painter.isActive())
+				paintEngineType = painter.paintEngine()->type();
+
+			painter.end();
+		}
+
+		if(!displayW || !displayH || !rgbDataBuffer || accelRender)
+			return ;
+
+		if(accelRender) 
+		{
+			if(lastImage)
+			{
+				accelRender->display(lastImage,displayW,displayH);
+			}
+		}
+		else
+		{
+			QImage image(rgbDataBuffer,displayW,displayH,QImage::Format_RGB32);
+			QPainter painter(this);
+			painter.drawImage(QPoint(0,0),image);
+			painter.end();
+		}
+	}
 };
+
 ADM_Qvideo *videoWindow=NULL;
 //****************************************************************************************************
 void UI_QT4VideoWidget(QFrame *host)
@@ -156,6 +209,15 @@ void  UI_updateDrawWindowSize(void *win,uint32_t w,uint32_t h)
 	if(rgbDataBuffer)
 		delete[] rgbDataBuffer;
 
+	if (displayW / 4 == w && displayH / 4 == h)
+		UI_setZoomMode(ZOOM_1_4);
+	else if (displayW / 2 == w && displayH / 2 == h)
+		UI_setZoomMode(ZOOM_1_2);
+	else if ((displayW == w && displayH == h) || displayW == 0)
+		UI_setZoomMode(ZOOM_1_1);
+	else if (displayW * 2 == w && displayH * 2 == h)
+		UI_setZoomMode(ZOOM_2);
+
 	rgbDataBuffer = new uint8_t[w * h * 4]; // 32 bits / color
 	displayW = w;
 	displayH = h;
@@ -207,6 +269,37 @@ void UI_getWindowInfo(void *draw, GUI_WindowInfo *xinfo)
 	xinfo->height = displayH;
 }
 
+// Calculate the zoom ratio required to fit the whole image on the screen.
+float UI_calcZoomToFitScreen(QWidget* window, QWidget* canvas, uint32_t imageWidth, uint32_t imageHeight)
+{
+	int windowWidth, windowHeight;
+	int drawingWidth, drawingHeight;
+	uint32_t screenWidth, screenHeight;
 
-//****************************************************************************************************
-//EOF 
+	windowWidth = window->frameSize().width();
+	windowHeight = window->frameSize().height();
+
+	drawingWidth = canvas->frameSize().width();
+	drawingHeight = canvas->frameSize().height();
+
+	UI_getPhysicalScreenSize(window, &screenWidth, &screenHeight);
+
+	// Take drawing area out of the equation, how much extra do we need for additional controls?
+	windowWidth -= drawingWidth;
+	windowHeight -= drawingHeight;
+
+	// This is the true amount of screen real estate we can work with
+	screenWidth -= windowWidth;
+	screenHeight -= windowHeight;
+
+	// Calculate zoom ratio
+	if (imageWidth > screenWidth || imageHeight > screenHeight)
+	{
+		float widthRatio = (float)screenWidth / (float)imageWidth;
+		float heightRatio = (float)screenHeight / (float)imageHeight;
+
+		return (widthRatio < heightRatio ? widthRatio : heightRatio);
+	}
+	else
+		return 1;
+}
