@@ -21,6 +21,7 @@
 #include "ADM_toolkit/filesel.h"
 #include "prefs.h"
 #include "ADM_assert.h"
+#include "../ADM_toolkit/qtToolkit.h"
     
 static void GUI_FileSelSelect(const char *label, char **name, uint32_t access) ;
 
@@ -78,26 +79,19 @@ void GUI_FileSelSelect(const char *label, char **name, uint32_t access)
         PathStripName(str);
         /* LASTDIR may have gone; then do nothing and use current dir instead (implied) */
         if( (dir=opendir(str)) )
-        {
                 closedir(dir);
-        } else 
-        {
-            delete [] str;
-            str=NULL;
-        }
   }
+
+  delete [] tmpname;
+
   QString fileName;
-  QFileDialog::Options options = 0;
 
-#if defined(__APPLE__)
-   options |= QFileDialog::DontUseNativeDialog;
-#endif
+   if(access)  fileName=QFileDialog::getSaveFileName(qtLastRegisteredDialog(), QString::fromUtf8(label), QString::fromUtf8(str));
+       else    fileName=QFileDialog::getOpenFileName(qtLastRegisteredDialog(), QString::fromUtf8(label), QString::fromUtf8(str));
 
-   if(access)  fileName=QFileDialog::getSaveFileName(NULL, label, str, NULL, NULL, options);
-       else    fileName=QFileDialog::getOpenFileName(NULL, label, str, NULL, NULL, options);
-
-  if(!fileName.isNull() )
+  if(!fileName.isNull())
   {
+	fileName = QDir::toNativeSeparators(fileName);
     const char *s=fileName.toUtf8().constData();
     *name=ADM_strdup(s);
     prefs->set(pref_entry,(ADM_filename *)*name);
@@ -118,24 +112,37 @@ void GUI_FileSelSelect(const char *label, char **name, uint32_t access)
 uint8_t FileSel_SelectWrite(const char *title,char *target,uint32_t max, const char *source)
 {
   char *dir=NULL,*tmpname=NULL;
-  QString fileName;
-  QFileDialog::Options options = 0;
+  QString defaultPath, fileName;
 
-#if defined(__APPLE__)
-  options |= QFileDialog::DontUseNativeDialog;
-#endif
+  if (source && *source)
+	  defaultPath = QString::fromUtf8(source);
+  else if (prefs->get(LASTDIR_WRITE, (ADM_filename **)&tmpname))
+  {
+	  DIR *dir;
+	  char *str = PathCanonize(tmpname);
 
-  fileName=QFileDialog::getSaveFileName(NULL, title, source, NULL, NULL, options);
+	  PathStripName(str);
+
+	  if (dir = opendir(str))
+		  closedir(dir);
+
+	  defaultPath = QString::fromUtf8(str);
+	  delete [] str;
+  }
+
+  delete [] tmpname;
+
+  fileName=QFileDialog::getSaveFileName(qtLastRegisteredDialog(), QString::fromUtf8(title), defaultPath);
 
   if(!fileName.isNull() )
   {
+	fileName = QDir::toNativeSeparators(fileName);
     const char *s=fileName.toUtf8().constData();
     strncpy(target,s,max);
-
-	return 1;
+	prefs->set(LASTDIR_WRITE, (ADM_filename *)s);
   }
   
-  return 0;
+  return !fileName.isNull();
 }
 /**
       \fn FileSel_SelectRead
@@ -150,24 +157,37 @@ uint8_t FileSel_SelectWrite(const char *title,char *target,uint32_t max, const c
 uint8_t FileSel_SelectRead(const char *title,char *target,uint32_t max, const char *source)
 {
   char *dir=NULL,*tmpname=NULL;
-  QString fileName;
-  QFileDialog::Options options = 0;
+  QString defaultPath, fileName;
 
-#if defined(__APPLE__)
-  options |= QFileDialog::DontUseNativeDialog;
-#endif
+  if (source && *source)
+	  defaultPath = QString::fromUtf8(source);
+  else if (prefs->get(LASTDIR_READ,(ADM_filename **)&tmpname))
+  {
+	  DIR *dir;
+	  char *str = PathCanonize(tmpname);
 
-  fileName = QFileDialog::getOpenFileName(NULL, title, source, NULL, NULL, options);
+	  PathStripName(str);
+
+	  if (dir = opendir(str))
+		  closedir(dir);
+
+	  defaultPath = QString::fromUtf8(str);
+	  delete [] str;
+  }
+
+  delete [] tmpname;
+
+  fileName = QFileDialog::getOpenFileName(qtLastRegisteredDialog(), QString::fromUtf8(title), defaultPath);
 
   if(!fileName.isNull() )
   {
+	fileName = QDir::toNativeSeparators(fileName);
     const char *s=fileName.toUtf8().constData();
     strncpy(target,s,max);
-
-	return 1;
+    prefs->set(LASTDIR_READ, (ADM_filename *)s);
   }
   
-  return 0;
+  return !fileName.isNull();
 }
 /**
       \fn FileSel_SelectDir
@@ -183,24 +203,37 @@ uint8_t FileSel_SelectRead(const char *title,char *target,uint32_t max, const ch
 uint8_t FileSel_SelectDir(const char *title,char *target,uint32_t max, const char *source)
 {
    char *dir=NULL,*tmpname=NULL;
-  
-   QString fileName;
-   QFileDialog::Options options = QFileDialog::ShowDirsOnly;
+   QString defaultPath, fileName;
 
-#if defined(__APPLE__)
-   options |= QFileDialog::DontUseNativeDialog;
-#endif
+   if (source && *source)
+	   defaultPath = QString::fromUtf8(source);
+   else if (prefs->get(LASTDIR_READ,(ADM_filename **)&tmpname))
+   {
+	   DIR *dir;
+	   char *str = PathCanonize(tmpname);
 
-   fileName=QFileDialog::getExistingDirectory(NULL, title, source, options);
+	   PathStripName(str);
+
+	   if (dir = opendir(str))
+		   closedir(dir);
+
+	   defaultPath = QString::fromUtf8(str);
+	   delete [] str;
+   }
+
+   delete [] tmpname;
+
+   fileName=QFileDialog::getExistingDirectory(qtLastRegisteredDialog(), QString::fromUtf8(title), defaultPath, QFileDialog::ShowDirsOnly);
 
   if(!fileName.isNull() )
   {
+	fileName = QDir::toNativeSeparators(fileName);
     const char *s=fileName.toUtf8().constData();
     strncpy(target,s,max);
-	return 1;
+	prefs->set(LASTDIR_READ, (ADM_filename *)s);
   }
 
-  return 0;
+  return !fileName.isNull();
 }
 
 
