@@ -28,8 +28,6 @@
 #define WIN32_CLASH
 #include "avi_vars.h"
 
-
-#include "avi_vars.h"
 #include "prototype.h"
 #include "ADM_toolkit/toolkit.hxx"
 #include "ADM_assert.h"
@@ -55,6 +53,7 @@
 #include "ADM_toolkit/filesel.h"
 #include "GUI_ui.h"
 #include "oplug_mpegFF/oplug_vcdff.h"
+#include "DIA_enter.h"
 
 static uint8_t  A_SaveAudioNVideo(const char *name);
  extern int A_SaveUnpackedVop(const char *name);
@@ -166,6 +165,8 @@ int ret=0;
 		
 	}
         printf("Output format:%d\n",UI_GetCurrentFormat());
+		char *path = fixupPath(name);
+
 	switch(family)
 	{
 		case CodecFamilyAVI:
@@ -173,35 +174,35 @@ int ret=0;
 					switch(UI_GetCurrentFormat())
 					{
 						case ADM_DUMMY:
-					                            			ret=oplug_dummy(name);
+					                            			ret=oplug_dummy(path);
 					                            			break;
 						case ADM_FLV:
-                            			ret=oplug_flv(name);
+                            			ret=oplug_flv(path);
                             			break;
                         case ADM_MP4:
                         case ADM_PSP:
                         case ADM_MATROSKA:
                         
-                                                    ret=oplug_mp4(name,UI_GetCurrentFormat());
+                                                    ret=oplug_mp4(path,UI_GetCurrentFormat());
                                                     break;
 						case ADM_AVI:
-								ret=A_SaveAudioNVideo(name);
+								ret=A_SaveAudioNVideo(path);
 								break;
 						case ADM_OGM:
-								ret=ogmSave(name);
+								ret=ogmSave(path);
 								break;
 						case ADM_ES:
-								ret=ADM_saveRaw(name);
+								ret=ADM_saveRaw(path);
 								break;
 						case ADM_AVI_DUAL:
-								ret=A_SaveAudioDualAudio(name);
+								ret=A_SaveAudioDualAudio(path);
 								break;
                                                 case ADM_AVI_PAK:
-								ret=A_SavePackedVop(name);
+								ret=A_SavePackedVop(path);
 								break;
 
 						case ADM_AVI_UNP:
-								ret=A_SaveUnpackedVop(name);
+								ret=A_SaveUnpackedVop(path);
 								break;
 						default:
                                                   GUI_Error_HIG(QT_TR_NOOP("Incompatible output format"), NULL);
@@ -217,7 +218,7 @@ int ret=0;
                                                 {
                                                   case ADM_PS:
                                                   case ADM_TS:
-						          ret=mpeg_passthrough(name,UI_GetCurrentFormat());
+						          ret=mpeg_passthrough(path,UI_GetCurrentFormat());
                                                           break;
                                                   default:
                                                     GUI_Error_HIG(QT_TR_NOOP("Incompatible output format"), NULL);
@@ -230,7 +231,7 @@ int ret=0;
                         case ADM_TS:
                         case ADM_PS:
                         case ADM_ES:
-                                ret=oplug_mpegff(name,UI_GetCurrentFormat());;
+                                ret=oplug_mpegff(path,UI_GetCurrentFormat());;
                                 break;
                         default:
                           GUI_Error_HIG(QT_TR_NOOP("Incompatible output format"), NULL);
@@ -238,9 +239,12 @@ int ret=0;
                     break;
                 default:
                             ADM_assert(0);
-                            return 0;
+							delete [] path;
+							return 0;
         }
         getFirstVideoFilter(0,avifileinfo->nb_frames);
+		delete [] path;
+
         return ret;
 }
 uint8_t  A_SaveAudioDualAudio(const char *inname)
@@ -341,10 +345,10 @@ uint8_t  A_SaveAudioNVideo(const char *name)
                   }
                   else
                   {
-                    if(GUI_Question(QT_TR_NOOP("You may need smart copy.\n Enable it ?")))
+                    if (GUI_Question(QT_TR_NOOP("You may need smart copy.\nEnable it?")))
                     {
                         value=4;
-                        if( ! GUI_getIntegerValue(&value, 2, 31, "_Q factor (set 4):"))
+                        if (!DIA_GetIntegerValue(&value, 2, 31, QT_TR_NOOP("Smart Copy"), QT_TR_NOOP("_Q factor (set 4):")))
                                       return 0;
                         nw=new   GenericAviSaveSmart(value);
                     }
